@@ -5,6 +5,8 @@
 
 #![cfg_attr(feature = "pedantic", warn(clippy::pedantic))]
 #![warn(clippy::use_self)]
+#![warn(clippy::map_flatten)]
+#![warn(clippy::map_unwrap_or)]
 #![warn(deprecated_in_future)]
 #![warn(future_incompatible)]
 #![warn(unreachable_pub)]
@@ -12,6 +14,7 @@
 #![warn(rust_2018_compatibility)]
 #![warn(rust_2018_idioms)]
 #![warn(unused)]
+#![allow(disjoint_capture_migration)]
 #![deny(warnings)]
 
 use location::Location;
